/***************************************************************************
                          setpageaudio.h  -  description
                             -------------------
    begin                : Thu Jan 10 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETPAGEAUDIO_H
#define SETPAGEAUDIO_H

#include <kcombobox.h>
#include <klineedit.h>
#include <tqwidget.h>
#include <tqhbox.h>
#include <tqvbox.h>
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqslider.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>
#include "resource.h"

/**
  *@author Troy Corbin Jr.
  */

class setPageAudio : public TQVBoxLayout
{
   TQ_OBJECT
  
	public:
										setPageAudio(TQWidget *parent=0, resource *Rsrc=0);
										~setPageAudio();
		void						buildThemeList( void );
		int							NewSounds;
		bool						changeTheme;
	signals:
		void						enableApply( void );
	public slots:
		void						slot_enableAudio( bool );
		void						slot_currentTheme( int );
		void						slot_currentVolume( int );
		void						slot_AudioCurrentOnly( bool );
	private:
		TQWidget 				*Parent;
		resource				*Resource;

		TQCheckBox							*BUTTON_enableAudio;
 			TQGroupBox							*GROUP_Theme;
 				KComboBox							*Current_Theme;
		TQHBox									*BOX_Main;
 			TQGroupBox							*GROUP_Volume;
 				TQLabel								*Vol_Min;
 				TQSlider								*Current_Volume;
 				TQLabel								*Vol_Max;
			TQVBox									*BOX_Options;
				TQCheckBox							*BUTTON_AudioCurrentOnly;
};

#endif
